ServerAllowHeaders class

Constructors

ServerAllowHeaders({required Set<String> headers, required bool inherit})
const
ServerAllowHeaders.fromDartObject(DartObject object)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Set<String>
final
inherit → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge(ServerAllowHeaders other) → ServerAllowHeaders
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited