ServerApp class

Mixed-in types

Constructors

ServerApp({required String className, required ServerImports importPath, required String constructor, required List<ServerParam> params, required ServerAppAnnotation appAnnotation, required ServerRouteAnnotations globalRouteAnnotations, required bool isSecure, required ServerAppObservers observers})
ServerApp.fromMeta(MetaAppConfig app)
factory

Properties

appAnnotation → ServerAppAnnotation
final
className → String
final
constructor → String
final
extractors → List<ExtractImport?>
no setteroverride
globalRouteAnnotations → ServerRouteAnnotations
final
hashCode → int
The hash code for this object.
no setterinherited
importPath → ServerImports
final
imports → List<ServerImports?>
no setteroverride
isSecure → bool
final
observers → ServerAppObservers
final
params → List<ServerParam>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited