ServerLifecycleComponentMethod class

Mixed-in types

Constructors

ServerLifecycleComponentMethod({required String name, required bool isFuture, required String returnType, required List<ServerParam> parameters, required String? exceptionType, required ServerImports import})

Properties

exceptionType → String?
The type of the exception that this method catches, If this method is not an exception catcher, this will be null
final
extractors → List<ExtractImport?>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
import → ServerImports
final
imports → List<ServerImports?>
no setteroverride
isExceptionCatcher → bool
no setter
isFuture → bool
final
isGuard → bool
no setter
isInterceptorPost → bool
no setter
isInterceptorPre → bool
no setter
isMiddleware → bool
no setter
isRequestWrapper → bool
no setter
name → String
final
parameters → List<ServerParam>
final
returnType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

aliasReturnTypes → Set<String>
final
coreReturnTypes → Set<String>
final
returnTypes → Set<String>
final

Static Methods

fromElement(MethodElement object, {Map<String, DartType> typeSubstitutions = const {}}) → ServerLifecycleComponentMethod?

Constants

interceptorPost → const String
interceptorPre → const String
nextResponse → const String
wrapperResult → const String