ServerPipe class

Mixed-in types

Constructors

ServerPipe({required ServerClass clazz, required ServerReflect? reflect, required ServerType convertFrom, required ServerType convertTo})

Properties

clazz → ServerClass
final
convertFrom → ServerType
final
convertTo → ServerType
final
extractors → List<ExtractImport?>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
imports → List<ServerImports>
no setteroverride
reflect → ServerReflect?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromType(DartType? type) → ServerPipe?