ServerRecordProp class

Mixed-in types

Constructors

ServerRecordProp({required String? name, required bool isNamed, required ServerType type})
ServerRecordProp.fromMeta(MetaRecordProp prop)
factory

Properties

extractors → List<ExtractImport?>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
imports → List<ServerImports?>
no setteroverride
isNamed → bool
final
isPositioned → bool
no setter
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ServerType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited