ServerReflect class

Mixed-in types

Constructors

ServerReflect({required String className, required ServerImports? importPath, required Map<String, List<ServerMimic>> metas})

Properties

className → String
final
extractors → List<ExtractImport?>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hasReflects → bool
no setter
importPath → ServerImports?
final
imports → List<ServerImports?>
no setteroverride
isValid → bool
no setter
metas → Map<String, List<ServerMimic>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromElement(Element? element) → ServerReflect?