ServerRoute class

Mixed-in types
Implementers

Constructors

ServerRoute({required List<ServerParam> params, required String handlerName, required ServerRouteAnnotations annotations})
ServerRoute.fromMeta(MetaMethod method)
factory

Properties

annotations → ServerRouteAnnotations
final
extractors → List<ExtractImport?>
no setteroverride
handlerName → String
final
hashCode → int
The hash code for this object.
no setterinherited
imports → List<ServerImports?>
no setteroverride
params → List<ServerParam>
final
pipes → List<ServerPipe>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited