ExtractImport mixin

Mixin applications

Properties

extractors → List<ExtractImport?>
no setter
hashCode → int
The hash code for this object.
no setterinherited
imports → List<ServerImports?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
pathImports() → Iterable<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited